@@ -27,8 +27,8 @@
 #include "plugin.h"
 #include "anjuta-msgman.h"
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-message-manager.ui"
-#define PREFS_GLADE PACKAGE_DATA_DIR"/glade/anjuta-message-manager-plugin.glade"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-message-manager.xml"
+#define PREFS_BUILDER PACKAGE_DATA_DIR"/glade/anjuta-message-manager-plugin.ui"
 
 /* Pixmaps */
 #define ANJUTA_PIXMAP_MESSAGES                "anjuta-messages-plugin-48.png"
@@ -56,6 +56,14 @@ static void on_prev_message(GtkAction* menuitem, MessageViewPlugin *plugin)
 		message_view_previous(view);
 }
 
+static void on_copy_message(GtkAction* menuitem, MessageViewPlugin *plugin)
+{
+	AnjutaMsgman* msgman = ANJUTA_MSGMAN(plugin->msgman);
+	MessageView* view = anjuta_msgman_get_current_view(msgman);
+	if (view != NULL)
+		message_view_copy(view);
+}
+
 static void on_save_message(GtkAction* menuitem, MessageViewPlugin *plugin)
 {
 	AnjutaMsgman* msgman = ANJUTA_MSGMAN(plugin->msgman);
@@ -65,7 +73,11 @@ static void on_save_message(GtkAction* menuitem, MessageViewPlugin *plugin)
 }
 
 static GtkActionEntry actions_goto[] = {
-  { "ActionMenuGoto", NULL, N_("_Goto"), NULL, NULL, NULL},
+  { "ActionMenuGoto", NULL, N_("_Go to"), NULL, NULL, NULL},
+  { "ActionMessageCopy", GTK_STOCK_COPY,
+    N_("_Copy Message"), NULL,
+	N_("Copy message"),
+    G_CALLBACK (on_copy_message)},
   { "ActionMessageNext", ANJUTA_STOCK_NEXT_MESSAGE,
     N_("_Next Message"), "<control><alt>n",
 	N_("Next message"),
@@ -82,17 +94,36 @@ static GtkActionEntry actions_goto[] = {
 
 static void on_view_changed(AnjutaMsgman* msgman, MessageViewPlugin* plugin)
 {
+	MessageView* view = anjuta_msgman_get_current_view (msgman);
 	AnjutaUI* ui = anjuta_shell_get_ui (ANJUTA_PLUGIN(plugin)->shell, NULL);
 	GtkAction* action_next = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
 								   "ActionMessageNext");
 	GtkAction* action_prev = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
 								   "ActionMessagePrev");
+	GtkAction* action_copy = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
+								   "ActionMessageCopy");
 	gboolean sensitive = (anjuta_msgman_get_current_view(msgman) != NULL);
 	if (sensitive)
 		anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell,
 								 GTK_WIDGET(msgman), NULL);
 	g_object_set (G_OBJECT (action_next), "sensitive", sensitive, NULL);
 	g_object_set (G_OBJECT (action_prev), "sensitive", sensitive, NULL);
+	g_object_set (G_OBJECT (action_copy), "sensitive", sensitive, NULL);
+
+	/* Toggle buttons */
+	gtk_widget_set_sensitive (plugin->normal, view != NULL);	
+	gtk_widget_set_sensitive (plugin->info, view != NULL);
+	gtk_widget_set_sensitive (plugin->warn, view != NULL);
+	gtk_widget_set_sensitive (plugin->error, view != NULL);
+	if (view)
+	{
+		MessageViewFlags flags =
+			message_view_get_flags (view);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(plugin->normal), flags & MESSAGE_VIEW_SHOW_NORMAL);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(plugin->info), flags & MESSAGE_VIEW_SHOW_INFO);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(plugin->warn), flags & MESSAGE_VIEW_SHOW_WARNING);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(plugin->error), flags & MESSAGE_VIEW_SHOW_ERROR);
+	}	
 }
 
 static gpointer parent_class;
@@ -184,7 +215,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	MessageViewPlugin *mv_plugin;
 	static gboolean initialized = FALSE;
 	
-	DEBUG_PRINT ("MessageViewPlugin: Activating MessageView plugin ...");
+	DEBUG_PRINT ("%s", "MessageViewPlugin: Activating MessageView plugin ...");
 	mv_plugin = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin);
 	
 	if (!initialized)
@@ -194,27 +225,26 @@ activate_plugin (AnjutaPlugin *plugin)
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	mv_plugin->action_group = 
 		anjuta_ui_add_action_group_entries (ui, "ActionGroupGotoMessages",
-											_("Next/Prev Message"),
+											_("Next/Previous Message"),
 											actions_goto,
 											G_N_ELEMENTS (actions_goto),
 											GETTEXT_PACKAGE, TRUE, plugin);
 	mv_plugin->uiid = anjuta_ui_merge (ui, UI_FILE);
 	popup = gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui), "/PopupMessageView");
 	mv_plugin->msgman = 
-		anjuta_msgman_new(anjuta_shell_get_preferences(plugin->shell, NULL), popup);
+		anjuta_msgman_new(popup);
 	g_signal_connect(G_OBJECT(mv_plugin->msgman), "view_changed", 
 					 G_CALLBACK(on_view_changed), mv_plugin);
 	GtkAction* action_next = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
 								   "ActionMessageNext");
 	GtkAction* action_prev = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
 								   "ActionMessagePrev");
+	GtkAction* action_copy = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
+								   "ActionMessageCopy");
 	g_object_set (G_OBJECT (action_next), "sensitive", FALSE, NULL);
 	g_object_set (G_OBJECT (action_prev), "sensitive", FALSE, NULL);
+	g_object_set (G_OBJECT (action_copy), "sensitive", FALSE, NULL);
 	
-	anjuta_shell_add_widget (plugin->shell, mv_plugin->msgman,
-							 "AnjutaMessageView", _("Messages"),
-							 "message-manager-plugin-icon",
-							 ANJUTA_SHELL_PLACEMENT_BOTTOM, NULL);
 #if 0
 	/* Connect to save and load session */
 	g_signal_connect (G_OBJECT (plugin->shell), "save-session",
@@ -223,6 +253,7 @@ activate_plugin (AnjutaPlugin *plugin)
 					  G_CALLBACK (on_session_load), plugin);
 #endif
 	initialized = TRUE;
+	mv_plugin->widget_shown = FALSE;
 	return TRUE;
 }
 
@@ -232,7 +263,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	MessageViewPlugin *mplugin;
 	AnjutaUI *ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	
-	DEBUG_PRINT ("MessageViewPlugin: Dectivating message view plugin ...");
+	DEBUG_PRINT ("%s", "MessageViewPlugin: Dectivating message view plugin ...");
 	
 	mplugin = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin);
 #if 0
@@ -244,8 +275,9 @@ deactivate_plugin (AnjutaPlugin *plugin)
 										  G_CALLBACK (on_session_load),
 										  plugin);
 #endif
-	/* Widget is destroyed as soon as it is removed */
-	anjuta_shell_remove_widget (plugin->shell, mplugin->msgman, NULL);
+	/* Widget is removed as soon as it is destroyed */
+	if (mplugin->widget_shown)
+		gtk_widget_destroy (mplugin->msgman);
 	anjuta_ui_unmerge (ui, mplugin->uiid);
 	anjuta_ui_remove_action_group (ui, mplugin->action_group);
 	
@@ -260,14 +292,14 @@ static void
 message_view_plugin_dispose (GObject *obj)
 {
 	// MessageViewPlugin *plugin = ANJUTA_PLUGIN_MESSAGE_VIEW (obj);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
 message_view_plugin_finalize (GObject *obj)
 {
 	// MessageViewPlugin *plugin = ANJUTA_PLUGIN_MESSAGE_VIEW (obj);
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -292,6 +324,120 @@ message_view_plugin_class_init (GObjectClass *klass)
 	klass->finalize = message_view_plugin_finalize;
 }
 
+static gboolean
+on_filter_button_tooltip (GtkWidget* widget, 
+                          gint        x,
+                          gint        y,
+                          gboolean    keyboard_mode,
+                          GtkTooltip *tooltip,
+                          MessageViewPlugin* plugin)
+{
+	gchar* temp = NULL;
+	MessageView* view = anjuta_msgman_get_current_view (ANJUTA_MSGMAN(plugin->msgman));
+	if (view)
+		return FALSE;
+	if (widget == plugin->normal)
+	{
+		temp = g_strdup_printf(ngettext ("%d Message", "%d Messages", 
+		                                 message_view_get_count (view,
+		                                                         MESSAGE_VIEW_SHOW_NORMAL)),
+		                       message_view_get_count (view,
+		                                               MESSAGE_VIEW_SHOW_NORMAL));
+		gtk_tooltip_set_text (tooltip, temp);
+	}
+	else if (widget == plugin->info)
+	{
+		temp = g_strdup_printf(ngettext ("%d Info", "%d Infos", 
+		                                 message_view_get_count (view,
+		                                                         MESSAGE_VIEW_SHOW_INFO)),
+		                       message_view_get_count (view,
+		                                               MESSAGE_VIEW_SHOW_INFO));
+		gtk_tooltip_set_text (tooltip, temp);
+	}
+	else if (widget == plugin->warn)
+	{
+		temp = g_strdup_printf(ngettext ("%d Warning", "%d Warnings", 
+		                                 message_view_get_count (view,
+		                                                         MESSAGE_VIEW_SHOW_WARNING)),
+		                       message_view_get_count (view,
+		                                               MESSAGE_VIEW_SHOW_WARNING));
+		gtk_tooltip_set_text (tooltip, temp);
+	}
+	else if (widget == plugin->error)
+	{
+		temp = g_strdup_printf(ngettext ("%d Error", "%d Errors", 
+		                                 message_view_get_count (view,
+		                                                         MESSAGE_VIEW_SHOW_ERROR)),
+		                       message_view_get_count (view,
+		                                               MESSAGE_VIEW_SHOW_ERROR));
+		gtk_tooltip_set_text (tooltip, temp);
+	}
+	else
+		g_assert_not_reached ();
+
+	return TRUE;
+}
+
+static void
+on_filter_buttons_toggled (GtkWidget* button, MessageViewPlugin *plugin)
+{
+	MessageViewFlags flags = 0;
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(plugin->normal)))
+		flags |= MESSAGE_VIEW_SHOW_NORMAL;
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(plugin->info)))
+		flags |= MESSAGE_VIEW_SHOW_INFO;
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(plugin->warn)))
+		flags |= MESSAGE_VIEW_SHOW_WARNING;
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(plugin->error)))
+		flags |= MESSAGE_VIEW_SHOW_ERROR;
+	message_view_set_flags (anjuta_msgman_get_current_view (ANJUTA_MSGMAN(plugin->msgman)),
+	                        flags);
+}
+
+static GtkWidget*
+create_mini_button (MessageViewPlugin* plugin, const gchar* stock_id)
+{
+	GtkWidget* button, *image;
+	gint h,w;
+	image = gtk_image_new_from_stock (stock_id, 
+	                                  GTK_ICON_SIZE_MENU);
+	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
+	button = gtk_toggle_button_new ();
+	g_signal_connect (G_OBJECT (button), "toggled",
+					  G_CALLBACK (on_filter_buttons_toggled), plugin);
+	gtk_container_add (GTK_CONTAINER (button), image);
+
+	g_object_set (button, "has-tooltip", TRUE, NULL);
+	g_signal_connect (button, "query-tooltip", 
+	                  G_CALLBACK (on_filter_button_tooltip), plugin);
+	
+	return button;
+}
+
+static void
+create_toggle_buttons (MessageViewPlugin* plugin,
+                       GtkWidget* hbox)
+{
+	GtkWidget* filter_buttons_box = gtk_hbox_new (FALSE, 0);
+	
+	plugin->normal = create_mini_button (plugin, "message-manager-plugin-icon");
+	plugin->info = create_mini_button (plugin, GTK_STOCK_INFO);
+	plugin->warn = create_mini_button (plugin, GTK_STOCK_DIALOG_WARNING);
+	plugin->error = create_mini_button (plugin, GTK_STOCK_DIALOG_ERROR);
+	
+	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (plugin->normal),
+						FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (plugin->info),
+						FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (plugin->warn),
+						FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (filter_buttons_box), GTK_WIDGET (plugin->error),
+	                    FALSE, FALSE, 0);
+	
+	gtk_widget_show_all (filter_buttons_box);
+	gtk_box_pack_start (GTK_BOX(hbox), filter_buttons_box, FALSE, FALSE, 0);
+}
+
 /*
  * IAnjutaMessagerManager interface implementation 
  */
@@ -303,6 +449,27 @@ ianjuta_msgman_add_view (IAnjutaMessageManager *plugin,
 	MessageView* message_view;
 	AnjutaShell* shell = ANJUTA_PLUGIN(plugin)->shell;
 	GtkWidget *msgman = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->msgman;
+	if (ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->widget_shown == FALSE)
+	{
+		GtkWidget* hbox = gtk_hbox_new (FALSE, 0);
+		GtkWidget* label = gtk_label_new (_("Messages"));
+		GtkWidget* image = gtk_image_new_from_stock ("message-manager-plugin-icon",
+		                                            GTK_ICON_SIZE_MENU);
+		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX(hbox), anjuta_msgman_get_tabber (ANJUTA_MSGMAN(msgman)),
+		                    TRUE, TRUE, 5);
+	
+		gtk_widget_show_all (hbox);
+
+		create_toggle_buttons (ANJUTA_PLUGIN_MESSAGE_VIEW(plugin), hbox);
+		
+		anjuta_shell_add_widget_custom (shell, msgman,
+							 "AnjutaMessageView", _("Messages"),
+							 "message-manager-plugin-icon", hbox,
+							 ANJUTA_SHELL_PLACEMENT_BOTTOM, NULL);
+		ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->widget_shown = TRUE;
+	}
 	anjuta_shell_present_widget(shell, msgman, NULL);
 	message_view = anjuta_msgman_add_view (ANJUTA_MSGMAN (msgman), file, icon);
 	return IANJUTA_MESSAGE_VIEW (message_view);
@@ -368,6 +535,26 @@ ianjuta_msgman_set_view_title (IAnjutaMessageManager *plugin,
 								  MESSAGE_VIEW (message_view), title);
 }
 
+static void
+ianjuta_msgman_set_view_icon_from_stock (IAnjutaMessageManager *plugin,
+							  IAnjutaMessageView *message_view,
+							  const gchar *icon, GError ** e)
+{
+	GtkWidget *msgman = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->msgman;
+	anjuta_msgman_set_view_icon_from_stock (ANJUTA_MSGMAN (msgman),
+								  MESSAGE_VIEW (message_view), icon);
+}
+
+static void
+ianjuta_msgman_set_view_icon (IAnjutaMessageManager *plugin,
+							  IAnjutaMessageView *message_view,
+							  GdkPixbufAnimation *icon, GError ** e)
+{
+	GtkWidget *msgman = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->msgman;
+	anjuta_msgman_set_view_icon (ANJUTA_MSGMAN (msgman),
+								 MESSAGE_VIEW (message_view), icon);
+}
+
 static void
 ianjuta_msgman_iface_init (IAnjutaMessageManagerIface *iface)
 {
@@ -378,6 +565,8 @@ ianjuta_msgman_iface_init (IAnjutaMessageManagerIface *iface)
 	iface->set_current_view = ianjuta_msgman_set_current_view;
 	iface->get_all_views = ianjuta_msgman_get_all_views;
 	iface->set_view_title = ianjuta_msgman_set_view_title;
+	iface->set_view_icon = ianjuta_msgman_set_view_icon;
+	iface->set_view_icon_from_stock = ianjuta_msgman_set_view_icon_from_stock;
 }
 
 static guint notify_id;
@@ -385,17 +574,23 @@ static guint notify_id;
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
-		GladeXML *gxml;
-		MessageViewPlugin* plugin = ANJUTA_PLUGIN_MESSAGE_VIEW (ipref);
-		/* Create the messages preferences page */
-		gxml = glade_xml_new (PREFS_GLADE, "preferences_dialog_messages", NULL);
-		anjuta_preferences_add_page (prefs, gxml,
+	GtkBuilder *bxml = gtk_builder_new ();
+	GError* error = NULL;
+	MessageViewPlugin* plugin = ANJUTA_PLUGIN_MESSAGE_VIEW (ipref);
+	/* Create the messages preferences page */
+
+	if (!gtk_builder_add_from_file (bxml, PREFS_BUILDER, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
+	anjuta_preferences_add_from_builder (prefs, bxml,
 									"Messages", _("Messages"),
 									 ANJUTA_PIXMAP_MESSAGES);
-		notify_id = anjuta_preferences_notify_add (prefs, MESSAGES_TABS_POS, 
-			on_gconf_notify_message_pref, plugin->msgman, NULL);
+	notify_id = anjuta_preferences_notify_add_string (prefs, MESSAGES_TABS_POS, 
+	                                                on_notify_message_pref, plugin->msgman, NULL);
 		
-		g_object_unref (gxml);
+	g_object_unref (bxml);
 }
 
 static void
